@@ -4,18 +4,11 @@
 #include "common/processing.h"
 #include "common/thread.h"
 #include "util/stringUtils.h"
-#include "util/mallocHelper.h"
 
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
 
-#if defined(__FreeBSD__) || defined(__APPLE__)
-    #include <sys/types.h>
-    #include <sys/user.h>
-    #include <sys/sysctl.h>
-#endif
-
 static void setExeName(FFstrbuf* exe, const char** exeName)
 {
     assert(exe->length > 0);
@@ -24,193 +17,8 @@ static void setExeName(FFstrbuf* exe, const char** exeName)
         *exeName = exe->chars + lastSlashIndex + 1;
 }
 
-static void getProcessInformation(pid_t pid, FFstrbuf* processName, FFstrbuf* exe, const char** exeName, FFstrbuf* exePath)
-{
-    assert(processName->length > 0);
-    ffStrbufClear(exe);
-
-    #ifdef __linux__
-
-    char filePath[64];
-    snprintf(filePath, sizeof(filePath), "/proc/%d/cmdline", (int)pid);
-
-    if(ffAppendFileBuffer(filePath, exe))
-    {
-        ffStrbufTrimRightSpace(exe);
-        ffStrbufRecalculateLength(exe); //Trim the arguments
-        ffStrbufTrimLeft(exe, '-'); //Login shells start with a dash
-    }
-
-    snprintf(filePath, sizeof(filePath), "/proc/%d/exe", (int)pid);
-    ffStrbufEnsureFixedLengthFree(exePath, PATH_MAX);
-    ssize_t length = readlink(filePath, exePath->chars, exePath->allocated - 1);
-    if (length > 0) // doesn't contain trailing NUL
-    {
-        exePath->chars[length + 1] = '\0';
-        exePath->length = (uint32_t) length;
-    }
-
-    #elif defined(__APPLE__)
-
-    size_t len = 0;
-    int mibs[] = { CTL_KERN, KERN_PROCARGS2, pid };
-    if (sysctl(mibs, sizeof(mibs) / sizeof(*mibs), NULL, &len, NULL, 0) == 0)
-    {
-        FF_AUTO_FREE char* const procArgs2 = malloc(len);
-        if (sysctl(mibs, sizeof(mibs) / sizeof(*mibs), procArgs2, &len, NULL, 0) == 0)
-        {
-            // https://gist.github.com/nonowarn/770696#file-getargv-c-L46
-            uint32_t argc = *(uint32_t*) procArgs2;
-            const char* realExePath = procArgs2 + sizeof(argc);
-
-            const char* arg0 = memchr(realExePath, '\0', len - (size_t) (realExePath - procArgs2));
-            ffStrbufSetNS(exePath, (uint32_t) (arg0 - realExePath), realExePath);
-
-            do arg0++; while (*arg0 == '\0');
-            assert(arg0 < procArgs2 + len);
-            if (*arg0 == '-') arg0++; // Login shells
-
-            ffStrbufSetS(exe, arg0);
-        }
-    }
-
-    #elif defined(__FreeBSD__)
-
-    size_t size = ARG_MAX;
-    FF_AUTO_FREE char* args = malloc(size);
-
-    static_assert(ARG_MAX > PATH_MAX, "");
-
-    if(sysctl(
-        (int[]){CTL_KERN, KERN_PROC, KERN_PROC_PATHNAME, pid}, 4,
-        args, &size,
-        NULL, 0
-    ) == 0)
-        ffStrbufSetNS(exePath, (uint32_t) (size - 1), args);
-
-    size = ARG_MAX;
-    if(sysctl(
-        (int[]){CTL_KERN, KERN_PROC, KERN_PROC_ARGS, pid}, 4,
-        args, &size,
-        NULL, 0
-    ) == 0)
-    {
-        char* arg0 = args;
-        size_t arg0Len = strlen(args);
-        if (size > arg0Len + 1)
-        {
-            char* p = (char*) memrchr(args, '/', arg0Len);
-            if (p)
-            {
-                p++;
-                if (ffStrStartsWith(p, "python")) // /usr/local/bin/python3.9 /home/carter/.local/bin/xonsh
-                {
-                    arg0 += arg0Len + 1;
-                }
-            }
-        }
-        if (arg0[0] == '-') arg0++;
-        ffStrbufSetS(exe, arg0);
-    }
-
-    #endif
-
-    if(exe->length == 0)
-        ffStrbufSet(exe, processName);
-
-    setExeName(exe, exeName);
-}
-
-static const char* getProcessNameAndPpid(pid_t pid, char* name, pid_t* ppid, int32_t* tty)
-{
-    if (pid <= 0)
-        return "Invalid pid";
-
-    #ifdef __linux__
-
-    char statFilePath[64];
-    snprintf(statFilePath, sizeof(statFilePath), "/proc/%d/stat", (int)pid);
-    char buf[PROC_FILE_BUFFSIZ];
-    ssize_t nRead = ffReadFileData(statFilePath, sizeof(buf) - 1, buf);
-    if(nRead < 0)
-        return "ffReadFileData(statFilePath, sizeof(buf)-1, buf) failed";
-    buf[nRead] = '\0';
-
-    *ppid = 0;
-    static_assert(sizeof(*ppid) == sizeof(int), "");
-
-    int tty_;
-    if(
-        sscanf(buf, "%*s (%255[^)]) %*c %d %*d %*d %d", name, ppid, &tty_) < 2 || //stat (comm) state ppid pgrp session tty
-        !ffStrSet(name) ||
-        *ppid == 0
-    )
-        return "sscanf(stat) failed";
-
-    if (tty)
-        *tty = tty_ & 0xFF;
-
-    #elif defined(__APPLE__)
-
-    struct kinfo_proc proc;
-    size_t size = sizeof(proc);
-    if(sysctl(
-        (int[]){CTL_KERN, KERN_PROC, KERN_PROC_PID, pid}, 4,
-        &proc, &size,
-        NULL, 0
-    ))
-        return "sysctl(KERN_PROC_PID) failed";
-
-    *ppid = (pid_t)proc.kp_eproc.e_ppid;
-    strcpy(name, proc.kp_proc.p_comm); //trancated to 16 chars
-    if (tty)
-    {
-        *tty = ((proc.kp_eproc.e_tdev >> 24) & 0xFF) == 0x10
-            ? proc.kp_eproc.e_tdev & 0xFFFFFF
-            : -1;
-    }
-
-    #elif defined(__FreeBSD__)
-
-    struct kinfo_proc proc;
-    size_t size = sizeof(proc);
-    if(sysctl(
-        (int[]){CTL_KERN, KERN_PROC, KERN_PROC_PID, pid}, 4,
-        &proc, &size,
-        NULL, 0
-    ))
-        return "sysctl(KERN_PROC_PID) failed";
-
-    *ppid = (pid_t)proc.ki_ppid;
-    strcpy(name, proc.ki_comm);
-    if (tty)
-    {
-        if (proc.ki_tdev != NODEV && proc.ki_flag & P_CONTROLT)
-        {
-            const char* ttyName = devname(proc.ki_tdev, S_IFCHR);
-            if (ffStrStartsWith(ttyName, "pts/"))
-                *tty = (int32_t) strtol(ttyName + strlen("pts/"), NULL, 10);
-            else
-                *tty = -1;
-        }
-        else
-            *tty = -1;
-    }
-
-    #else
-
-    return "Unsupported platform";
-
-    #endif
-
-    return NULL;
-}
-
 static pid_t getShellInfo(FFShellResult* result, pid_t pid)
 {
-    char name[256];
-    name[0] = '\0';
-
     pid_t ppid = 0;
     int32_t tty = -1;
 
@@ -223,33 +31,36 @@ static pid_t getShellInfo(FFShellResult* result, pid_t pid)
             userShellName = instance.state.platform.userShell.chars + index + 1;
     }
 
-    while (getProcessNameAndPpid(pid, name, &ppid, &tty) == NULL)
+    while (ffProcessGetBasicInfoLinux(pid, &result->processName, &ppid, &tty) == NULL)
     {
-        if (!ffStrEquals(userShellName, name))
+        if (!ffStrbufEqualS(&result->processName, userShellName))
         {
             //Common programs that are between terminal and own process, but are not the shell
             if(
                 // tty < 0                                  || //A shell should connect to a tty
-                ffStrEquals(name, "sh")                  || //This prevents us from detecting things like pipes and redirects, i hope nobody uses plain `sh` as shell
-                ffStrEquals(name, "sudo")                ||
-                ffStrEquals(name, "su")                  ||
-                ffStrEquals(name, "strace")              ||
-                ffStrEquals(name, "sshd")                ||
-                ffStrEquals(name, "gdb")                 ||
-                ffStrEquals(name, "lldb")                ||
-                ffStrEquals(name, "lldb-mi")             ||
-                ffStrEquals(name, "login")               ||
-                ffStrEquals(name, "ltrace")              ||
-                ffStrEquals(name, "perf")                ||
-                ffStrEquals(name, "guake-wrapped")       ||
-                ffStrEquals(name, "time")                ||
-                ffStrEquals(name, "hyfetch")             || //when hyfetch uses fastfetch as backend
-                ffStrContainsIgnCase(name, "debug")      ||
-                ffStrContainsIgnCase(name, "not-found")  ||
-                ffStrEndsWith(name, ".sh")
+                ffStrbufEqualS(&result->processName, "sh")                  || //This prevents us from detecting things like pipes and redirects, i hope nobody uses plain `sh` as shell
+                ffStrbufEqualS(&result->processName, "sudo")                ||
+                ffStrbufEqualS(&result->processName, "su")                  ||
+                ffStrbufEqualS(&result->processName, "strace")              ||
+                ffStrbufEqualS(&result->processName, "sshd")                ||
+                ffStrbufEqualS(&result->processName, "gdb")                 ||
+                ffStrbufEqualS(&result->processName, "lldb")                ||
+                ffStrbufEqualS(&result->processName, "lldb-mi")             ||
+                ffStrbufEqualS(&result->processName, "login")               ||
+                ffStrbufEqualS(&result->processName, "ltrace")              ||
+                ffStrbufEqualS(&result->processName, "perf")                ||
+                ffStrbufEqualS(&result->processName, "guake-wrapped")       ||
+                ffStrbufEqualS(&result->processName, "time")                ||
+                ffStrbufEqualS(&result->processName, "hyfetch")             || //when hyfetch uses fastfetch as backend
+                ffStrbufEqualS(&result->processName, "clifm")               || //https://github.com/leo-arch/clifm/issues/289
+                ffStrbufEqualS(&result->processName, "valgrind")            ||
+                ffStrbufContainS(&result->processName, "debug")             ||
+                ffStrbufContainS(&result->processName, "not-found")         ||
+                ffStrbufEndsWithS(&result->processName, ".sh")
             )
             {
                 pid = ppid;
+                ffStrbufClear(&result->processName);
                 continue;
             }
         }
@@ -257,8 +68,7 @@ static pid_t getShellInfo(FFShellResult* result, pid_t pid)
         result->pid = (uint32_t) pid;
         result->ppid = (uint32_t) ppid;
         result->tty = tty;
-        ffStrbufSetS(&result->processName, name);
-        getProcessInformation(pid, &result->processName, &result->exe, &result->exeName, &result->exePath);
+        ffProcessGetInfoLinux(pid, &result->processName, &result->exe, &result->exeName, &result->exePath);
         break;
     }
     return ppid;
@@ -266,58 +76,65 @@ static pid_t getShellInfo(FFShellResult* result, pid_t pid)
 
 static pid_t getTerminalInfo(FFTerminalResult* result, pid_t pid)
 {
-    char name[256];
-    name[0] = '\0';
-
     pid_t ppid = 0;
 
-    while (getProcessNameAndPpid(pid, name, &ppid, NULL) == NULL)
+    while (ffProcessGetBasicInfoLinux(pid, &result->processName, &ppid, NULL) == NULL)
     {
         //Known shells
         if (
-            ffStrEquals(name, "sh")         ||
-            ffStrEquals(name, "ash")        ||
-            ffStrEquals(name, "bash")       ||
-            ffStrEquals(name, "zsh")        ||
-            ffStrEquals(name, "ksh")        ||
-            ffStrEquals(name, "mksh")       ||
-            ffStrEquals(name, "oksh")       ||
-            ffStrEquals(name, "csh")        ||
-            ffStrEquals(name, "tcsh")       ||
-            ffStrEquals(name, "fish")       ||
-            ffStrEquals(name, "dash")       ||
-            ffStrEquals(name, "pwsh")       ||
-            ffStrEquals(name, "nu")         ||
-            ffStrEquals(name, "git-shell")  ||
-            ffStrEquals(name, "elvish")     ||
-            ffStrEquals(name, "oil.ovm")    ||
-            ffStrEquals(name, "xonsh")      || // works in Linux but not in macOS because kernel returns `Python` in this case
-            ffStrEquals(name, "login")      ||
-            ffStrEquals(name, "sshd")       ||
-            ffStrEquals(name, "chezmoi")    || // #762
+            ffStrbufEqualS(&result->processName, "sh")         ||
+            ffStrbufEqualS(&result->processName, "ash")        ||
+            ffStrbufEqualS(&result->processName, "bash")       ||
+            ffStrbufEqualS(&result->processName, "zsh")        ||
+            ffStrbufEqualS(&result->processName, "ksh")        ||
+            ffStrbufEqualS(&result->processName, "mksh")       ||
+            ffStrbufEqualS(&result->processName, "oksh")       ||
+            ffStrbufEqualS(&result->processName, "csh")        ||
+            ffStrbufEqualS(&result->processName, "tcsh")       ||
+            ffStrbufEqualS(&result->processName, "fish")       ||
+            ffStrbufEqualS(&result->processName, "dash")       ||
+            ffStrbufEqualS(&result->processName, "pwsh")       ||
+            ffStrbufEqualS(&result->processName, "nu")         ||
+            ffStrbufEqualS(&result->processName, "git-shell")  ||
+            ffStrbufEqualS(&result->processName, "elvish")     ||
+            ffStrbufEqualS(&result->processName, "oil.ovm")    ||
+            ffStrbufEqualS(&result->processName, "xonsh")      || // works in Linux but not in macOS because kernel returns `Python` in this case
+            ffStrbufEqualS(&result->processName, "login")      ||
+            ffStrbufEqualS(&result->processName, "sshd")       ||
+            ffStrbufEqualS(&result->processName, "clifm")      || // https://github.com/leo-arch/clifm/issues/289
+            ffStrbufEqualS(&result->processName, "chezmoi")    || // #762
             #ifdef __linux__
-            ffStrStartsWith(name, "flatpak-") || // #707
+            ffStrbufStartsWithS(&result->processName, "flatpak-") || // #707
             #endif
-            ffStrEndsWith(name, ".sh")
+            ffStrbufEndsWithS(&result->processName, ".sh")
         )
         {
             pid = ppid;
+            ffStrbufClear(&result->processName);
             continue;
         }
 
         #ifdef __APPLE__
         // https://github.com/fastfetch-cli/fastfetch/discussions/501
-        if (ffStrEndsWith(name, " (figterm)") || ffStrEndsWith(name, " (cwterm)"))
+        const char* pLeft = strstr(result->processName.chars, " (");
+        if (pLeft)
         {
-            if (__builtin_expect(getProcessNameAndPpid(ppid, name, &ppid, NULL) != NULL, false))
-                return 0;
+            pLeft += 2;
+            const char* pRight = strstr(pLeft, "term)");
+            if (pRight && pRight[5] == '\0')
+            {
+                for (; pLeft < pRight; ++pLeft)
+                    if (*pLeft < 'a' || *pLeft > 'z')
+                        break;
+                if (pLeft == pRight && ffProcessGetBasicInfoLinux(ppid, &result->processName, &ppid, NULL) != NULL)
+                    return 0;
+            }
         }
         #endif
 
         result->pid = (uint32_t) pid;
         result->ppid = (uint32_t) ppid;
-        ffStrbufSetS(&result->processName, name);
-        getProcessInformation(pid, &result->processName, &result->exe, &result->exeName, &result->exePath);
+        ffProcessGetInfoLinux(pid, &result->processName, &result->exe, &result->exeName, &result->exePath);
         break;
     }
     return ppid;
@@ -331,11 +148,9 @@ static bool getTerminalInfoByPidEnv(FFTerminalResult* result, const char* pidEnv
 
     pid_t pid = (pid_t) strtol(envStr, NULL, 10);
     result->pid = (uint32_t) pid;
-    char name[256];
-    if (getProcessNameAndPpid(pid, name, (pid_t*) &result->ppid, NULL) == NULL)
+    if (ffProcessGetBasicInfoLinux(pid, &result->processName, (pid_t*) &result->ppid, NULL) == NULL)
     {
-        ffStrbufSetS(&result->processName, name);
-        getProcessInformation(pid, &result->processName, &result->exe, &result->exeName, &result->exePath);
+        ffProcessGetInfoLinux(pid, &result->processName, &result->exe, &result->exeName, &result->exePath);
         return true;
     }
 
