@@ -6,6 +6,7 @@
 #include "modules/bios/option.h"
 #include "modules/bluetooth/option.h"
 #include "modules/board/option.h"
+#include "modules/bootmgr/option.h"
 #include "modules/break/option.h"
 #include "modules/brightness/option.h"
 #include "modules/camera/option.h"
@@ -21,11 +22,13 @@
 #include "modules/disk/option.h"
 #include "modules/diskio/option.h"
 #include "modules/display/option.h"
+#include "modules/editor/option.h"
 #include "modules/font/option.h"
 #include "modules/host/option.h"
 #include "modules/gamepad/option.h"
 #include "modules/gpu/option.h"
 #include "modules/icons/option.h"
+#include "modules/initsystem/option.h"
 #include "modules/kernel/option.h"
 #include "modules/loadavg/option.h"
 #include "modules/locale/option.h"
